dashboard.Widget (Widget) — amici1

# `dashboard.Widget` (Widget)

Master tables : dashboard.AllWidgets (All dashboard widgets), dashboard.Widgets (Widgets)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- No. (seqno) : The sequence number of this item with its parent.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Resource (item_name) : See `<django.db.models.fields.CharField: item_name>`.

- Visible (visible) : See `<django.db.models.fields.BooleanField: visible>`.

- Label (title) : See `lino.modlib.dashboard.models.Widget.title`.

- Name (name_column) : See `lino.modlib.dashboard.models.Widget.name_column`.

- (None) (navigation_panel) : See `lino.modlib.dashboard.models.Widget.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.dashboard.models.Widget.overview`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
seqno | No. | The sequence number of this item with its parent.
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
item_name | Resource |
visible | Visible |
title | Label |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
move_buttons | Move | Displays buttons for certain actions on this row: